//! Archive compression algorithms

pub mod rar;
pub mod sevenz;
pub mod tar;
pub mod zip;
